@@ -24,7 +24,6 @@
 #include "waylandintegration.h"
 
 #include <QDateTime>
-#include <QObject>
 #include <QMap>
 
 #include <gbm.h>
@@ -39,7 +38,6 @@ namespace KWayland {
         class ConnectionThread;
         class EventQueue;
         class FakeInput;
-        class OutputDevice;
         class Registry;
         class RemoteAccessManager;
         class RemoteBuffer;
